@@ -19,24 +19,21 @@ def toggl_to_redmine(config):
 
     entries_logged = []
     entries_not_logged = []
-    redmine_exception = None
-
-    all_previous_entries_were_saved = True
 
     for time_entry in time_entries:
-        if all_previous_entries_were_saved:
+        if time_entry.should_be_imported():
             try:
                 redmine.save_entry(time_entry)
                 entries_logged.append(time_entry)
             except RedmineIntegrationException as e:
+                time_entry.message = str(e)
                 entries_not_logged.append(time_entry)
-                all_previous_entries_were_saved = False
-                redmine_exception = e
         else:
             entries_not_logged.append(time_entry)
+    
+    toggl.update_saved_entries(entries_logged)
 
-    if redmine_exception != None:
-        redmine_exception.set_pending_entries(entries_not_logged)
-        raise redmine_exception
-
-    return entries_logged
+    return {
+        'entries_saved': entries_logged,
+        'entries_not_saved': entries_not_logged
+    }
